"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandManager = exports.Command = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
class Command {
    constructor({ name, aliases, run, info }) {
        this.name = name;
        this.aliases = aliases;
        this.run = run;
        this.info = info;
    }
}
exports.Command = Command;
class CommandManager {
    constructor(prefix) {
        this.prefix = prefix;
        this.commands = new Map();
        this.aliases = new Map();
    }
    logCommands(commandDirPath) {
        return __awaiter(this, void 0, void 0, function* () {
            fs_1.readdir(commandDirPath, (err, files) => __awaiter(this, void 0, void 0, function* () {
                if (err)
                    return console.error(err);
                for (const fileName of files) {
                    const filePath = path_1.join(commandDirPath, fileName);
                    if (fileName.endsWith(`.${process.env.EXTENSION || 'js'}`)) {
                        const imported = yield Promise.resolve().then(() => __importStar(require(filePath)));
                        if (!imported.default || !(imported.default instanceof Command))
                            return;
                        const command = imported.default;
                        this.commands.set(command.name, command);
                        command.aliases.map(alias => this.aliases.set(alias, command.name));
                        continue;
                    }
                    if (fs_1.lstatSync(filePath).isDirectory())
                        this.logCommands(filePath);
                }
            }));
        });
    }
    get(commandQueryString) {
        return __awaiter(this, void 0, void 0, function* () {
            const alias = this.aliases.get(commandQueryString);
            const command = alias ? this.commands.get(alias) : this.commands.get(commandQueryString);
            return command ? command : Promise.reject();
        });
    }
    getSync(commandQueryString) {
        const alias = this.aliases.get(commandQueryString);
        const command = alias ? this.commands.get(alias) : this.commands.get(commandQueryString);
        return command ? command : undefined;
    }
    parseAndGet(msg) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            if (msg.author.bot || !msg.content.startsWith(this.prefix))
                return Promise.reject({ isParsed: false });
            const args = msg.content.slice(this.prefix.length).trim().split(/ +/);
            const commandQueryString = (_a = args.shift()) === null || _a === void 0 ? void 0 : _a.toLowerCase();
            if (!commandQueryString)
                return Promise.reject({ isParsed: false });
            const command = this.getSync(commandQueryString);
            return command ? { command, args }
                : Promise.reject({ isParsed: true, command: commandQueryString, args });
        });
    }
}
exports.CommandManager = CommandManager;
//# sourceMappingURL=index.js.map